pub struct MinimalUsername(/* private fields */);Expand description
A wrapper around a custom string-like type that implements the minimal set of required traits for a braid type
Implementations
Sourceimpl MinimalUsername
impl MinimalUsername
Sourcepub const fn from_str(raw: &str) -> &Self
pub const fn from_str(raw: &str) -> &Self
Transparently reinterprets the string slice as a strongly-typed MinimalUsername
Sourcepub const fn from_static(raw: &'static str) -> &'static Self
pub const fn from_static(raw: &'static str) -> &'static Self
Transparently reinterprets the static string slice as a strongly-typed MinimalUsername
Sourcepub fn into_owned(self: Box<MinimalUsername>) -> MinimalUsernameBuf
pub fn into_owned(self: Box<MinimalUsername>) -> MinimalUsernameBuf
Converts a Box<MinimalUsername> into a MinimalUsernameBuf without copying or allocating