pub struct LowerString(/* private fields */);Expand description
A non-empty String normalized to lowercase
This type maintains an invariant that ensures that a value of this type cannot be constructed that contains invalid data. Data that can be normalized to a valid instance of this type will be.
Because this type does normalization, the type explicitly
does not implement Borrow<str>,
as doing so would could violate the contract of that trait,
potentially resulting in lost data. If a user of
the crate would like to override this, then they can
explicitly implement the trait.
This type includes an explicit parameter indicating that
the borrowed form of this type should be named LowerStr.
Implementations
Sourceimpl LowerString
impl LowerString
Sourcepub fn new(raw: String) -> Result<Self, <LowerString as Validator>::Error>
pub fn new(raw: String) -> Result<Self, <LowerString as Validator>::Error>
Constructs a new LowerString if it conforms to LowerString and normalizes the input
Sourcepub const unsafe fn new_unchecked(raw: String) -> Self
pub const unsafe fn new_unchecked(raw: String) -> Self
Constructs a new LowerString without validation or normalization
Safety
Consumers of this function must ensure that values conform to LowerString and are in normalized form. Failure to maintain this invariant may lead to undefined behavior.
Sourcepub fn from_static(raw: &'static str) -> Self
pub fn from_static(raw: &'static str) -> Self
Constructs a new LowerString from a static reference if it conforms to LowerString, normalizing the input
Panics
This function will panic if the provided raw string is not valid.
Sourcepub fn into_boxed_ref(self) -> Box<LowerStr>
pub fn into_boxed_ref(self) -> Box<LowerStr>
Converts this LowerString into a Box<LowerStr>
This will drop any excess capacity.