An example of constructing a basic strongly-typed wrapper around
a Bytes-backed value.
The types in this module do not perform any validation or normalization of their values, so every valid UTF-8 string is potentially valid for these types.
Note: This example requires the bytestring-facet feature, which enables
facet’s bytestring feature for bytestring::ByteString support.