An example of constructing a strongly-typed wrapper around a string with small-string optimization.
The types in this module do not perform any validation or normalization of their values, so every valid UTF-8 string is potentially valid for these types.
Note: This example requires the smartstring-facet and compact_str-facet
features, which enable facet’s smartstring and compact_str features for
smartstring::SmartString and compact_str::CompactString support.